@@ -1,13 +1,36 @@
 from django.template import Library, Node, TemplateSyntaxError
 from django.utils.safestring import mark_safe, SafeText
 
-from ..base import detect_backend, SoundCloudBackend
+from ..backends import detect_backend, SoundCloudBackend
 
 register = Library()
 
 
 @register.tag('video')
 class VideoNode(Node):
+    """
+    Template tag ``video``. It gives access to all
+    :py:class:`~embed_video.backends.VideoBackend` variables.
+
+    Usage:
+
+    .. code-block:: html+django
+
+        {% video URL as VAR %}
+            ...
+        {% endvideo %}
+
+    Example:
+
+    .. code-block:: html+django
+
+        {% video item.video as my_video %}
+            URL: {{ my_video.url }}
+            Thumbnail: {{ my_video.thumbnail }}
+            Backend: {{ my_video.backend }}
+        {% endvideo %}
+
+    """
     error_msg = ('Syntax error. Expected: ``video source as var``')
 
     def __init__(self, parser, token):
@@ -39,12 +62,44 @@ class VideoNode(Node):
 
 
 @register.filter(is_safe=True)
-def embed(backend, _size='small'):
+def embed(backend, size='small'):
+    """
+    Shortcut for :py:func:`VideoNode` tag.
+
+    Usage:
+
+    .. code-block:: html+django
+
+        {{ URL|embed:SIZE }}
+
+    Example:
+
+    .. code-block:: html+django
+
+        {{ 'http://www.youtube.com/watch?v=guXyvo2FfLs'|embed:'large' }}
+
+    Predefined sizes:
+
+        ======== ======== =========
+        size     width    height
+        ======== ======== =========
+        tiny     420      315
+        small    480      360
+        medium   640      480
+        large    960      720
+        huge     1280     960
+        ======== ======== =========
+
+    You can also use custom size - in format ``WIDTHxHEIGHT``
+    (eg. ``500x400``).
+
+    """
+
     if isinstance(backend, SafeText):
         backend = detect_backend(backend)
 
-    size = _embed_get_size(_size)
-    params = _embed_get_params(backend, size)
+    _size = _embed_get_size(size)
+    params = _embed_get_params(backend, _size)
 
     return mark_safe(
         '<iframe width="%(width)d" height="%(height)d" '
